@@ -1,12 +1,11 @@
 from computemate import config, DIALOGS, AGENTMAKE_CONFIG, COMPUTEMATE_USER_DIR
 from prompt_toolkit.input import create_input
 from prompt_toolkit.layout import Layout, HSplit
-from prompt_toolkit.widgets import Frame, Label
 from prompt_toolkit.styles import Style, merge_styles
 from prompt_toolkit.application import Application
 from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.completion import WordCompleter, FuzzyCompleter
-from prompt_toolkit.widgets import Frame, TextArea
+from prompt_toolkit.widgets import Frame, TextArea, Label
 from prompt_toolkit.layout.menus import CompletionsMenu
 from prompt_toolkit.layout import WindowAlign
 from prompt_toolkit.lexers import PygmentsLexer
@@ -16,12 +15,11 @@ from pygments.styles import get_style_by_name
 from agentmake import agentmake, DEFAULT_TEXT_EDITOR, edit_file, readTextFile, writeTextFile
 from agentmake.etextedit import launch_async
 from agentmake.utils.files import searchFolder
-from typing import Any, Optional
 from pathlib import Path
 import os, re, glob
 
 
-async def getTextArea(input_suggestions:list=None, default_entry="", title="", multiline:bool=True, completion:Optional[Any]=None, scrollbar:bool=True, read_only:bool=False):
+async def getTextArea(input_suggestions:list=None, default_entry="", title="", multiline:bool=True, scrollbar:bool=True, read_only:bool=False):
     """Get text area input with a border frame"""
 
     if config.current_prompt and not default_entry:
@@ -33,7 +31,7 @@ async def getTextArea(input_suggestions:list=None, default_entry="", title="", m
     pygments_style = get_style_by_name('github-dark')
     markdown_style = style_from_pygments_cls(pygments_style)
     # Define custom style
-    custom_style = Style.from_dict({
+    frame_style = {
         #'frame.border': '#00ff00',  # Green border
         #'frame.label': '#ffaa00 bold',  # Orange label
         #'completion-menu': 'bg:#008888 #ffffff',
@@ -41,8 +39,10 @@ async def getTextArea(input_suggestions:list=None, default_entry="", title="", m
         #'completion-menu.completion.current': 'bg:#00aaaa #000000',
         #"status": "reverse",
         "textarea": "bg:#1E1E1E",
-    })
-
+    }
+    if config.agent_mode is not None:
+        frame_style["frame.border"] = config.color_agent_mode if config.agent_mode else config.color_partner_mode
+    custom_style = Style.from_dict(frame_style)
     style = merge_styles([markdown_style, custom_style])
 
     # TextArea with a completer
@@ -60,62 +60,6 @@ async def getTextArea(input_suggestions:list=None, default_entry="", title="", m
     )
     text_area.buffer.cursor_position = len(text_area.text)
 
-    def unpack_text_chunks(_):
-        openai_style = True if config.backend in ("azure", "azure_any", "custom", "deepseek", "github", "github_any", "googleai", "groq", "llamacpp", "mistral", "openai", "xai") else False
-        first_event = True
-        chat_response = ""
-        for event in completion:
-            # RETRIEVE THE TEXT FROM THE RESPONSE
-            if event is None:
-                continue
-            elif openai_style:
-                # openai
-                # when open api key is invalid for some reasons, event response in string
-                if isinstance(event, str):
-                    answer = event
-                elif hasattr(event, "data") and hasattr(event.data, "choices"): # mistralai
-                    try:
-                        answer = event.data.choices[0].delta.content
-                    except:
-                        answer = None
-                elif hasattr(event, "choices") and not event.choices: # in case of the 1st event of azure's completion
-                    continue
-                else:
-                    answer = event.choices[0].delta.content or ""
-            elif hasattr(event, "type") and event.type == "content-delta" and hasattr(event, "delta"): # cohere
-                answer = event.delta.message.content.text
-            elif hasattr(event, "delta") and hasattr(event.delta, "text"): # anthropic
-                answer = event.delta.text
-            elif hasattr(event, "content_block") and hasattr(event.content_block, "text"):
-                answer = event.content_block.text
-            elif str(type(event)).startswith("<class 'anthropic.types"): # anthropic
-                continue
-            elif hasattr(event, "message"): # newer ollama python package
-                answer = event.message.content
-            elif isinstance(event, dict):
-                if "message" in event:
-                    # ollama chat
-                    answer = event["message"].get("content", "")
-                else:
-                    # llama.cpp chat
-                    answer = event["choices"][0]["delta"].get("content", "")
-            elif hasattr(event, "text"):
-                # vertex ai, genai
-                answer = event.text
-            else:
-                #print(event)
-                answer = None
-            # STREAM THE ANSWER
-            if answer is not None:
-                if first_event:
-                    first_event = False
-                    answer = answer.lstrip()
-                # update the chat response
-                chat_response += answer
-                # display the chunk in the text area
-                text_area.buffer.insert_text(answer)
-                text_area.buffer.cursor_position = len(text_area.text)
-
     def edit_temp_file(initial_content: str) -> str:
         config.current_prompt = ""
         temp_file = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))), "temp", "edit.md")
@@ -304,7 +248,6 @@ async def getTextArea(input_suggestions:list=None, default_entry="", title="", m
         #mouse_support=True, # If enabled; content outside the app becomes unscrollable
         input=create_input(always_prefer_tty=True),
         full_screen=False,
-        after_render=unpack_text_chunks if completion is not None else None,
     )
     
     # Run the app
